pub struct WorkloadIdentity { /* private fields */ }Expand description
Implements a client for the Workload Identity API.
Example
use google_cloud_lro::Poller;
async fn sample(
) -> anyhow::Result<()> {
let client = WorkloadIdentity::builder().build().await?;
let response = client.generate_service_agents()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Service Description
Service describing handlers for resources
Configuration
To configure WorkloadIdentity use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://workloadidentity.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
WorkloadIdentity holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap WorkloadIdentity in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl WorkloadIdentity
impl WorkloadIdentity
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for WorkloadIdentity.
let client = WorkloadIdentity::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: WorkloadIdentity + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: WorkloadIdentity + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn generate_service_agents(&self) -> GenerateServiceAgents
pub fn generate_service_agents(&self) -> GenerateServiceAgents
Creates all service agents for a given resource, location and service producer.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_workloadidentity_v1::Result;
async fn sample(
client: &WorkloadIdentity
) -> Result<()> {
let response = client.generate_service_agents()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
This method lists locations based on the resource scope provided in
the ListLocationsRequest.name field: *
Global locations: If name is empty, the method lists the
public locations available to all projects. * Project-specific
locations: If name follows the format
projects/{project}, the method lists locations visible to that
specific project. This includes public, private, or other
project-specific locations enabled for the project.
For gRPC and client library implementations, the resource name is
passed as the name field. For direct service calls, the resource
name is
incorporated into the request path based on the specific service
implementation and version.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_workloadidentity_v1::Result;
async fn sample(
client: &WorkloadIdentity
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_workloadidentity_v1::Result;
async fn sample(
client: &WorkloadIdentity
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_workloadidentity_v1::Result;
async fn sample(
client: &WorkloadIdentity
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_workloadidentity_v1::Result;
async fn sample(
client: &WorkloadIdentity
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_workloadidentity_v1::Result;
async fn sample(
client: &WorkloadIdentity
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_workloadidentity_v1::Result;
async fn sample(
client: &WorkloadIdentity
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for WorkloadIdentity
impl Clone for WorkloadIdentity
Sourcefn clone(&self) -> WorkloadIdentity
fn clone(&self) -> WorkloadIdentity
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for WorkloadIdentity
impl !UnwindSafe for WorkloadIdentity
impl Freeze for WorkloadIdentity
impl Send for WorkloadIdentity
impl Sync for WorkloadIdentity
impl Unpin for WorkloadIdentity
impl UnsafeUnpin for WorkloadIdentity